@@ -69,6 +69,14 @@ impl EdgeContainer for AdjacencyListStorage {
         Box::new(std::iter::empty())
     }
 
+    fn has_outgoing_edges(&self, node: NodeID) -> bool {
+        if let Some(outgoing) = self.edges.get(&node) {
+            !outgoing.is_empty()
+        } else {
+            false
+        }
+    }
+
     fn get_ingoing_edges<'a>(&'a self, node: NodeID) -> Box<dyn Iterator<Item = NodeID> + 'a> {
         if let Some(ingoing) = self.inverse_edges.get(&node) {
             return match ingoing.len() {
