@@ -20,7 +20,9 @@ pub const DEFAULT_MAX_NUMBER_OF_TABLES: usize = 32;
 const KB: usize = 1 << 10;
 const MB: usize = KB * KB;
 const BLOCK_MAX_SIZE: usize = 4 * KB;
-const BLOCK_CACHE_CAPACITY: usize = MB;
+
+/// Uses a cache for each disk table with 1 MB capacity.
+pub const DEFAULT_BLOCK_CACHE_CAPACITY: usize = MB;
 
 #[derive(Serialize, Deserialize)]
 struct Entry<K, V>
@@ -42,17 +44,14 @@ impl Default for EvictionStrategy {
     }
 }
 
-fn custom_options() -> sstable::Options {
-    sstable::Options::default().with_cache_capacity(BLOCK_CACHE_CAPACITY / BLOCK_MAX_SIZE)
-}
-
 pub struct DiskMap<K, V>
 where
     K: 'static + KeySerializer + Send + Sync,
     for<'de> V: 'static + Serialize + Deserialize<'de> + Send + Sync,
 {
     eviction_strategy: EvictionStrategy,
-    max_number_of_tables: usize,
+    max_number_of_tables: Option<usize>,
+    block_cache_capacity: usize,
     c0: BTreeMap<KeyVec, Option<V>>,
     /// A vector of on-disk tables holding the evicted data.
     disk_tables: Vec<Table>,
@@ -78,7 +77,8 @@ where
     pub fn new(
         persisted_file: Option<&Path>,
         eviction_strategy: EvictionStrategy,
-        max_number_of_tables: usize,
+        max_number_of_tables: Option<usize>,
+        block_cache_capacity: usize,
     ) -> Result<DiskMap<K, V>> {
         let mut disk_tables = Vec::default();
 
@@ -93,6 +93,7 @@ where
         Ok(DiskMap {
             eviction_strategy,
             max_number_of_tables,
+            block_cache_capacity,
             c0: BTreeMap::default(),
             disk_tables,
             insertion_was_sorted: true,
@@ -105,6 +106,32 @@ where
         })
     }
 
+    pub fn new_temporary(
+        eviction_strategy: EvictionStrategy,
+        max_number_of_tables: Option<usize>,
+        block_cache_capacity: usize,
+    ) -> DiskMap<K, V> {
+        DiskMap {
+            eviction_strategy,
+            max_number_of_tables,
+            block_cache_capacity,
+            c0: BTreeMap::default(),
+            disk_tables: Vec::default(),
+            insertion_was_sorted: true,
+            unchanged_from_disk: false,
+            last_inserted_key: None,
+
+            serialization: bincode::options(),
+            phantom: std::marker::PhantomData,
+            est_sum_memory: 0,
+        }
+    }
+
+    fn custom_options(&self) -> sstable::Options {
+        let blocks = (self.block_cache_capacity / BLOCK_MAX_SIZE).max(1);
+        sstable::Options::default().with_cache_capacity(blocks)
+    }
+
     pub fn insert(&mut self, key: K, value: V) -> Result<()> {
         self.unchanged_from_disk = false;
 
@@ -168,7 +195,11 @@ where
             self.disk_tables.len() + 1
         };
 
-        if num_of_tables > self.max_number_of_tables {
+        let needs_compacting = self
+            .max_number_of_tables
+            .map(|max_number_of_tables| num_of_tables > max_number_of_tables)
+            .unwrap_or(false);
+        if needs_compacting {
             debug!("Compacting disk tables");
             // Directly compact the existing tables and the C0,
             // which will also evict the C0 table.
@@ -177,7 +208,7 @@ where
             debug!("Evicting DiskMap C0 to temporary file");
             let out_file = tempfile::tempfile()?;
 
-            let mut builder = TableBuilder::new(custom_options(), &out_file);
+            let mut builder = TableBuilder::new(self.custom_options(), &out_file);
 
             for (key, value) in self.c0.iter() {
                 let key = key.create_key();
@@ -189,7 +220,7 @@ where
 
             self.est_sum_memory = 0;
             let size = out_file.metadata()?.len();
-            let table = Table::new(custom_options(), Box::new(out_file), size as usize)?;
+            let table = Table::new(self.custom_options(), Box::new(out_file), size as usize)?;
             self.disk_tables.push(table);
 
             self.c0.clear();
@@ -473,7 +504,7 @@ where
 
         // Create single temporary sorted string file by iterating over all entries
         let out_file = tempfile::tempfile()?;
-        let mut builder = TableBuilder::new(custom_options(), &out_file);
+        let mut builder = TableBuilder::new(self.custom_options(), &out_file);
         for (key, value) in self.try_iter()? {
             let key = key.create_key();
             builder.add(&key, &self.serialization.serialize(&Some(value))?)?;
@@ -481,7 +512,7 @@ where
         let size = builder.finish()?;
 
         // Re-open sorted string table and set it as the only table
-        let table = Table::new(custom_options(), Box::new(out_file), size)?;
+        let table = Table::new(self.custom_options(), Box::new(out_file), size)?;
         self.disk_tables = vec![table];
         self.c0.clear();
 
@@ -507,7 +538,7 @@ where
             .read(true)
             .create(true)
             .open(&location)?;
-        let mut builder = TableBuilder::new(custom_options(), out_file);
+        let mut builder = TableBuilder::new(self.custom_options(), out_file);
         for (key, value) in self.try_iter()? {
             let key = key.create_key();
             builder.add(&key, &self.serialization.serialize(&Some(value))?)?;
@@ -527,7 +558,8 @@ where
         DiskMap::new(
             None,
             EvictionStrategy::default(),
-            DEFAULT_MAX_NUMBER_OF_TABLES,
+            Some(DEFAULT_MAX_NUMBER_OF_TABLES),
+            DEFAULT_BLOCK_CACHE_CAPACITY,
         )
         .expect("Temporary disk map creation should not fail.")
     }
